@@ -1,24 +1,3 @@
-HEADER__security = "Authentication-Token"
-HEADER__security_bypass = "Authentication-Token-Bypass"
-
-SQL__where = "WHERE"
-SQL__order_by = "ORDER BY"
-SQL__limit = "LIMIT"
-SQL__offset = "OFFSET"
-SQL__asc = "ASC"
-SQL__desc = "DESC"
-SQL__and = "AND"
-SQL__or = "OR"
-SQL__like = "LIKE"
-SQL__eq = "="
-SQL__paren_open = "("
-SQL__paren_close = ")"
-SQL__single_quote = "'"
-SQL__double_quote = '"'
-SQL__lower = "lower"
-SQL__varchar_cast = "::varchar"
-SQL__is_null = "is null"
-
 KEY__username = "username"
 KEY__password = "password"
 KEY__attach_as = "attach_as"
@@ -69,6 +48,7 @@ EXAMPLE__jwt = "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.e30.yXvILkvUUCBqAFlAv6wQ1Q-
 
 VAULT_KEY__db_crypt_key = "db_crypt_key"
 VAULT_KEY__db_repeatable_salt = "repeatable_salt"
+VAULT_KEY__super_local_access_key = "super_access_key"
 VAULT_KEY__jaaql_local_access_key = "jaaql_access_key"
 VAULT_KEY__super_db_credentials = "super_db_credentials"
 VAULT_KEY__jaaql_lookup_connection = "jaaql_lookup_connection"
@@ -121,13 +101,14 @@ DB__jaaql = "jaaql"
 DB__postgres = "postgres"
 
 PORT__ems = 6061
+PORT__mms = 6062
 
 ENDPOINT__send_email = "/send-email"
+ENDPOINT__execute_migrations = "/internal/migrations"
 ENDPOINT__internal_applications = "/internal/applications"
 ENDPOINT__internal_templates = "/internal/emails/templates"
 ENDPOINT__internal_accounts = "/internal/emails/accounts"
 ENDPOINT__is_alive = "/internal/is-alive"
-ENDPOINT__jaaql_emails = "/emails"
 ENDPOINT__report_sentinel_error = "/sentinel/reporting/error"
 ENDPOINT__install = "/internal/install"
 
@@ -147,5 +128,5 @@ ROLE__postgres = "postgres"
 
 PROTOCOL__postgres = "postgresql://"
 
-VERSION = "4.6.0"
+VERSION = "4.7.3"
 
