@@ -17,6 +17,8 @@ from jaaql.constants import *
 from jaaql.mvc.model import JAAQLModel
 from jaaql.mvc.response import JAAQLResponse
 from typing import Union
+from jaaql.utilities.utils import create_interface_for_db
+from monitor.main import HEADER__security, HEADER__security_bypass_jaaql, HEADER__security_bypass
 
 from jaaql.openapi.swagger_documentation import SwaggerDocumentation, SwaggerMethod, TYPE__response, \
     SwaggerFlatResponse, REST__DELETE, REST__GET, REST__OPTIONS, REST__POST, REST__PUT, SwaggerList, SwaggerResponse, \
@@ -30,6 +32,7 @@ ARG__response = "response"
 ARG__username = "username"
 ARG__profiler = "profiler"
 ARG__auth_token = "auth_token"
+ARG__auth_token_for_refresh = "auth_token_for_refresh"
 ARG__connection = "connection"
 ARG__is_the_anonymous_user = "is_the_anonymous_user"
 ARG__verification_hook = "verification_hook"
@@ -80,6 +83,9 @@ BOOL__allowed = {
     "false": False
 }
 
+IPS__local = [
+    "127.0.0.1", "localhost"
+]
 
 class BaseJAAQLController:
 
@@ -429,7 +435,24 @@ class BaseJAAQLController:
                     ip_addr = request.headers.get(HEADER__real_ip, request.remote_addr).split(",")[0]
 
                     if swagger_documentation.security:
-                        if verification_hook:
+                        bypass_super = request.headers.get(HEADER__security_bypass)
+                        bypass_jaaql = request.headers.get(HEADER__security_bypass_jaaql)
+                        if bypass_super or bypass_jaaql:
+                            if ip_addr not in IPS__local:
+                                raise HttpStatusException("Bypass used in none local context", HTTPStatus.UNAUTHORIZED)
+                            miss_super_bypass = bypass_super and bypass_super != self.model.local_super_access_key
+                            miss_jaaql_bypass = bypass_jaaql and bypass_jaaql != self.model.local_super_access_key
+                            if miss_super_bypass or miss_jaaql_bypass:
+                                raise HttpStatusException("Invalid bypass key", HTTPStatus.UNAUTHORIZED)
+
+                            is_public = False
+                            username = USERNAME__super_db if bypass_super else USERNAME__jaaql
+                            account_id, ip_id = self.model.get_bypass_user(username, ip_addr)
+
+                            if verification_hook:
+                                verification_hook.put((True, None, None))
+
+                        elif verification_hook:
                             account_id, username, ip_id, is_public = self.model.verify_auth_token_threaded(request.headers.get(HEADER__security),
                                                                                                            ip_addr, verification_hook)
                             self.perform_profile(request_id, "Verify JWT Threaded")
@@ -461,12 +484,14 @@ class BaseJAAQLController:
                                 if not swagger_documentation.security:
                                     raise Exception(ERR__method_required_user_connection)
                                 connect_db = arg.split(ARG_START__connection)[1]
-                                supply_dict[arg] = self.model.create_interface_for_db(account_id, connect_db, sub_role=account_id)
+                                supply_dict[arg] = create_interface_for_db(self.model.vault, self.model.config, account_id, connect_db,
+                                                                           sub_role=account_id)
 
                         for arg in inspect.getfullargspec(view_func_local).args:
                             if arg.startswith(ARG_START__jaaql_connection):
                                 connect_db = arg.split(ARG_START__jaaql_connection)[1]
-                                supply_dict[arg] = self.model.create_interface_for_db(account_id, connect_db, sub_role=ROLE__jaaql)
+                                supply_dict[arg] = create_interface_for_db(self.model.vault, self.model.config, account_id, connect_db,
+                                                                           sub_role=ROLE__jaaql)
 
                         if ARG__username in inspect.getfullargspec(view_func_local).args:
                             if not swagger_documentation.security:
@@ -484,10 +509,13 @@ class BaseJAAQLController:
                                 raise Exception(ERR__method_required_token)
                             supply_dict[ARG__auth_token] = request.headers.get(HEADER__security)
 
+                        if ARG__auth_token_for_refresh in inspect.getfullargspec(view_func_local).args:
+                            supply_dict[ARG__auth_token_for_refresh] = request.headers.get(HEADER__security)
+
                         if ARG__connection in inspect.getfullargspec(view_func_local).args:
                             if not swagger_documentation.security:
                                 raise Exception(ERR__method_required_connection)
-                            supply_dict[ARG__connection] = self.model.create_interface_for_db(account_id, DB__jaaql)
+                            supply_dict[ARG__connection] = create_interface_for_db(self.model.vault, self.model.config, account_id, DB__jaaql)
 
                         if ARG__is_the_anonymous_user in inspect.getfullargspec(view_func_local).args:
                             if not swagger_documentation.security:
